summaryrefslogtreecommitdiffstats
path: root/kmail/subscriptiondialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/subscriptiondialog.h')
-rw-r--r--kmail/subscriptiondialog.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/subscriptiondialog.h b/kmail/subscriptiondialog.h
index 4d3a01db..9d16c9e2 100644
--- a/kmail/subscriptiondialog.h
+++ b/kmail/subscriptiondialog.h
@@ -50,7 +50,7 @@ namespace KMail {
TQ_OBJECT
public:
- SubscriptionDialogBase( TQWidget *tqparent,
+ SubscriptionDialogBase( TQWidget *parent,
const TQString &caption,
KAccount* acct,
TQString startPath = TQString() );
@@ -60,10 +60,10 @@ namespace KMail {
protected:
/**
* Find the tqparent item
*/
void findParentItem ( TQString &name, TQString &path, TQString &compare,
- GroupItem **tqparent, GroupItem **oldItem );
+ GroupItem **parent, GroupItem **oldItem );
/**
* Process the next prefix in mPrefixList
@@ -131,7 +131,7 @@ namespace KMail {
TQ_OBJECT
public:
- SubscriptionDialog( TQWidget *tqparent,
+ SubscriptionDialog( TQWidget *parent,
const TQString &caption,
KAccount* acct,
TQString startPath = TQString() );
@@ -60,10 +60,10 @@ namespace KMail {
protected:
/**
- * Find the tqparent item
+ * Find the parent item
*/
void findParentItem ( TQString &name, TQString &path, TQString &compare,